@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "guard/commands/notification"
 
 RSpec.describe Guard::Commands::Notification do
@@ -9,8 +11,8 @@ RSpec.describe Guard::Commands::Notification do
 
   before do
     allow(FakePry).to receive(:output).and_return(output)
-    allow(Pry::Commands).to receive(:create_command).
-      with("notification") do |&block|
+    allow(Pry::Commands).to receive(:create_command)
+      .with("notification") do |&block|
       FakePry.instance_eval(&block)
     end
 
